.. include:: ../README.rst


Narrative documentation
-----------------------
.. toctree::
   :maxdepth: 2

   connstring
   usage_zmi
   development
   contributors
   changes


API documentation
-----------------
.. toctree::
   :maxdepth: 2

   api_da


Indices and tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
